"""
projectkiwi3
~~~~~~~~~~~~~~~~~~~~~~~~

This module is a means for interfacing with projectkiwi using python.


Classes:
    - Client: A class to interface with project kiwi

Example:
    To get started, try this:

    >>> from projectkiwi3 import Client
    >>> client = Client("my_key)


Author:
    Your Name <michael@projectkiwi.io>
    
License:
    MIT License (if applicable)
"""


# your_package/__init__.py
from .Client import Client

__version__ = "0.1.1"
